breed [ moths moth ]
breed [ darknesses darkness ]
breed [ players player ]

players-own 
[
  user-name 
  caught 
  attempts
  percent
]

;; gene-frequencies determine the color
;; of each moth and mutate as moths reproduce
moths-own [
  red-pigment-gene-frequency 
  blue-pigment-gene-frequency 
  green-pigment-gene-frequency
]

globals [
  ticks-during-day
  night?
  total-caught
  mutation-step 
  gene-limits?
  number-players
  leader  
  leader-caught
]

to startup
  hubnet-set-client-interface "COMPUTER" [ "clients/Bug Hunters Camouflage client.nlogo" ]
  hubnet-reset
  setup-clear
end

to setup-clear
  ca
  set total-caught 0
  set number-players 0
  set ticks-during-day 0
  set night? false 
  set gene-limits? true
  set leader ""
  set leader-caught 0
   set mutation-step 1
   create-custom-darknesses 1 [ 
     set color black 
     set size (max-pxcor * 3) 
     ht 
     set shape "square"
   ] 
  import-drawing environment
  make-initial-moths   
end

to setup
  cp
  clear-all-plots
  ask moths[ die ]
  set total-caught 0
  set night? false 
  set leader ""
  set leader-caught 0
  import-drawing environment
  make-initial-moths
  ask players [ initialize-player ]
end

;;;;;;;;;;;;;;;;;;;
;; Setup Procedures
;;;;;;;;;;;;;;;;;;;

to make-initial-moths
  create-custom-moths number-moths [
    set size moth-size
    set shape "moth"
    set red-pigment-gene-frequency precision (random-float 11) 1 
    set blue-pigment-gene-frequency precision (random-float 11) 1
    set green-pigment-gene-frequency precision (random-float 11) 1
    setxy random-xcor random-ycor
    display-genotype-labels
    set-phenotype-color
  ]
end

;;;;;;;;;;;;;;;;;;;;;
;; Runtime Procedures
;;;;;;;;;;;;;;;;;;;;;

to go
  set ticks-during-day (ticks-during-day + 1) ;; tick counter used to cycle to day and night
  cycle-to-daytime
  if ticks-during-day > day-length 
  [
    do-plots
    cycle-to-nighttime
  ]
  ask moths [ 
    display-genotype-labels 
    set size moth-size 
  ]
  reproduce-moths
  
  every 0.01 [ listen-clients ]
end

;; keep a stable population of moths as predation rates go up or down
to reproduce-moths   
  ;; if all the moths are removed by predators at once
  ;; make a new batch of random moths
  if count moths = 0  
  [ make-initial-moths ]  
  
  ;; otherwise reproduce random other moths  until  
  ;; you've reached the carrying capacity
  while [ count moths < number-moths ]      
  [ ask one-of moths [ make-one-offspring ] ]    
end

to eat-moths
  ;; extract the coords from the hubnet message
  let clicked-xcor  (item 0 hubnet-message)
  let clicked-ycor  (item 1 hubnet-message)   
   
  ask players with [ user-name = hubnet-message-source ] [
    set xcor clicked-xcor set ycor clicked-ycor      ;; go to the location of the click
    set attempts attempts + 1                        ;; each mouse click is recorded as as an attempt 
                                                     ;; for that player
 
    ;;  if the players clicks close enough to a moth's location, they catch it
    ;;  the in-radius (moth-size / 2) calculation helps make sure the user catches the moth 
    ;;  if they click within one shape radius (approximately since the shape of the moth isn't
    ;;  a perfect circle, even if the size of the moth is other than 1)
    
    if any? moths in-radius (moth-size / 2)  
    [
      let doomed-moth one-of moths in-radius (moth-size / 2)
      set caught caught + 1
      set total-caught total-caught + 1
       ask doomed-moth
         [ die ]
    ]
  ]
end

to make-one-offspring ;; turtle procedure
  ;; three possible random mutations can occur, one in each frequency of gene expression
  ;; mutations can increase, decrease, or have no change on the gene-frequency  
  let red-gene-mutation ((random-float (mutation-step + 1)) - (random-float (mutation-step + 1)))
  let green-gene-mutation ((random-float (mutation-step + 1)) - (random-float (mutation-step + 1)))
  let blue-gene-mutation ((random-float (mutation-step + 1)) - (random-float (mutation-step + 1)))

  hatch 1 [
    set red-pigment-gene-frequency precision (red-pigment-gene-frequency  + red-gene-mutation) 1
    set green-pigment-gene-frequency precision (green-pigment-gene-frequency  + green-gene-mutation) 1
    set blue-pigment-gene-frequency precision (blue-pigment-gene-frequency  + blue-gene-mutation) 1
    if gene-limits? [ set-genotype-limits ]
    set-phenotype-color
    wander-offspring
  ]
end

;;  ask all moths to reproduce, ignoring carrying-capacity limits
to make-generation     
  ask moths [ make-one-offspring ]
end

;; randomly place the offspring of a moth within an offspring radius of its parent
to wander-offspring   ;; turtle procedure 
  rt random-float 360
  fd random-float (offspring-distance + 1)
end

;; move all the moths during the night within a wander-distance-at-night range
to night-wander ;; turtle procedure 
   rt random-float 360
   fd random-float (wander-distance-at-night + 1)
end

;; convert the genetic representation of gene frequency 
;; into a phenotype using the rgb primitive
to set-phenotype-color  ;; turtle procedure
  set color ( rgb (red-pigment-gene-frequency / 10) 
                  (green-pigment-gene-frequency / 10) 
                  (blue-pigment-gene-frequency / 10) )
end

;; imposes a threshold limit on gene-frequency.
;; without this genes could drift into negative values or very large values
;; the rgb calculation will still work on these values without the limit, but
;; the limits can help make data analysis of the rgb values easier
to set-genotype-limits
  if (red-pigment-gene-frequency < 0) 
    [ set red-pigment-gene-frequency 0 ]
  if (green-pigment-gene-frequency < 0) 
    [ set green-pigment-gene-frequency 0 ]
  if (blue-pigment-gene-frequency < 0) 
    [ set blue-pigment-gene-frequency 0 ]

  if (red-pigment-gene-frequency > 10) 
    [ set red-pigment-gene-frequency 10 ]
  if (green-pigment-gene-frequency > 10) 
    [ set green-pigment-gene-frequency 10 ]
  if (blue-pigment-gene-frequency > 10) 
    [ set blue-pigment-gene-frequency 10 ]
end

;;;;;;;;;;;;;;;;;;;;;;
;; Visualization Procedures
;;;;;;;;;;;;;;;;;;;;;;

;; a visualization technique to find moths if the player(s) are convinced they are not there anymore
;; the moths will flash without permanently changing the color attribute of the moths
to flash-moths                  
  ask moths  [  
    repeat 3 [
      set shape "moth-black"
      wait 0.1
      set shape "moth-white"
      wait 0.1
    ]
    set shape "moth"
  ]
end

to display-genotype-labels  ;; turtle procedure
  ifelse show-genotype?
   [ set label red-pigment-gene-frequency + " "  
               + green-pigment-gene-frequency + " " 
               + blue-pigment-gene-frequency ]
   [ set label ""]
end

;; cycling between night and day simply shows and hides a single large turtle that is black to simulate 
;; making the background black and covering the moths in darkness without actually 
;; removing the imported drawing.  During nighttime, the location of the moths might change
to cycle-to-nighttime
  if day-night? [ 
    ask darknesses [ set hidden? false ]
    set night? true
    ask moths [night-wander]
  ]
end

;; after a period of time (night-wait) expires, 
;; the darkness changes back to the regular daytime environment
to cycle-to-daytime  
  if (day-night? and night?) [
    wait night-wait 
    ask darknesses [ set hidden? true ] 
    set night? false 
    set ticks-during-day 0
  ]
end

;;;;;;;;;;;;;;;;;;;;;;
;; HubNet Procedures
;;;;;;;;;;;;;;;;;;;;;;

to add-player
  set number-players number-players + 1
  create-custom-players 1 [
    set user-name hubnet-message-source
    initialize-player
  ]
end

to initialize-player
  set attempts 0
  set caught 0
  set hidden? true
  set-percent
  send-student-info
end

to remove-player 
  set number-players (number-players - 1)
  ask players with [ user-name = hubnet-message-source ] 
    [ die ]
end

to set-percent
  ifelse leader-caught > 0 
  [ set percent ((caught / leader-caught) * 100)]
  [ set percent 0 ]
end

to send-student-info
  hubnet-send user-name  "Your name" user-name
  hubnet-send user-name "You have caught" caught
  hubnet-send user-name "# Attempts"  attempts
  hubnet-send user-name "Relative %"  (precision percent 2)          
  hubnet-send user-name "Top hunter" leader
  hubnet-send user-name "Top hunter's catches" leader-caught         
end

to listen-clients
  while [hubnet-message-waiting?]
  [
    hubnet-fetch-message
    ifelse hubnet-enter-message?
    [add-player]

    [
      ifelse hubnet-exit-message?
     [remove-player]
     [
        if ((hubnet-message-tag = "View")  )
         [
            ask players with [ user-name = hubnet-message-source ]
              [ eat-moths ]

            update-leader-stats

            ;; update all the players anytime we update the leaders
            ask players
            [
              set-percent
              send-student-info
            ]            
         ]
      ]
    ]
  ]  
end

to update-leader-stats
  if any? players
  [
    let leaders players with-max [ caught ]
    let number-leaders count leaders

    ifelse number-leaders > 1 
    [ set leader number-leaders + "-way tie" ]  
    [ ask one-of leaders [set leader user-name ] ]
    set leader-caught caught-of one-of leaders
  ]
end

;;;;;;;;;;;;;;;;;;;;;
;; Plotting Procedure
;;;;;;;;;;;;;;;;;;;;;
to do-plots
  set-current-plot "Bugs Caught"
  plot total-caught
end


; *** NetLogo 3.1.2 Model Copyright Notice ***
;
; Copyright 2006 by Uri Wilensky.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2006).  NetLogo HubNet Bug Hunters Camouflage model.
; http://ccl.northwestern.edu/netlogo/models/HubNetBugHuntersCamouflage.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; In other publications, please use:
; Copyright 2006 Uri Wilensky.  All rights reserved.
; See http://ccl.northwestern.edu/netlogo/models/HubNetBugHuntersCamouflage
; for terms of use.
;
; *** End of NetLogo 3.1.2 Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
350
10
770
451
20
20
10.0
1
10
1
1
1
0
1
1
1
-20
20
-20
20

CC-WINDOW
5
627
779
722
Command Center
0

BUTTON
177
17
296
69
NIL
setup
NIL
1
T
OBSERVER
T
NIL

BUTTON
177
72
296
123
NIL
go
T
1
T
OBSERVER
NIL
NIL

MONITOR
6
328
86
377
total caught
total-caught
0
1

SLIDER
4
10
151
43
number-moths
number-moths
0
100
50
1
1
NIL

SLIDER
158
183
317
216
offspring-distance
offspring-distance
1.0
20.0
5.0
1
1
NIL

CHOOSER
356
457
488
502
environment
environment
"seashore.jpg" "glacier.jpg" "poppyfield.jpg"
2

BUTTON
491
463
625
496
change background
import-drawing environment
NIL
1
T
OBSERVER
T
NIL

BUTTON
5
145
91
178
flash
flash-moths
NIL
1
T
OBSERVER
T
NIL

SWITCH
5
183
155
216
show-genotype?
show-genotype?
1
1
-1000

SLIDER
5
107
152
140
moth-size
moth-size
0.1
10
1.0
0.1
1
NIL

BUTTON
95
145
212
178
make a generation
make-generation\nask moths [display-genotype-labels]
NIL
1
T
OBSERVER
T
NIL

SWITCH
6
220
122
253
day-night?
day-night?
0
1
-1000

SLIDER
6
290
208
323
night-wait
night-wait
0
10
1.1
0.1
1
seconds

SLIDER
6
256
208
289
wander-distance-at-night
wander-distance-at-night
0.0
10.0
5.0
1
1
NIL

SLIDER
127
220
320
253
day-length
day-length
0
500
80
10
1
ticks

MONITOR
213
264
324
313
NIL
ticks-during-day
0
1

PLOT
6
375
341
613
Bugs Caught
days
bugs
0.0
100.0
0.0
50.0
true
false

BUTTON
628
463
768
496
clear background
cd
NIL
1
T
OBSERVER
T
NIL

@#$#@#$#@
WHAT IS IT?
-----------
A HubNet activity that shows how camouflaging can evolve very quickly within a population that has hunters hunting it.  

In this activity, different colored bugs move around an environment. The users try to hunt as many bugs as they can by clicking on them. When a bug is eaten, another bug appears with a random color and location. After many generations, this process usually results in a bug population that blends into the background.

When a hunter uses color and shape to identify the location of prey in an environment, then the interaction of the colors and patterns of the prey amongst the colors and patterns in the environment provide additional selective pressure on the prey.  If some prey tend to blend into the background better, these prey tend to survive longer and reproduce more often.  If this continues over many generations, the distribution of colors in a population may shift to become more camouflaged with respect to the surrounding environment.


HOW IT WORKS
------------
Each HubNet participant or player assumes the role of a predator.  When the HubNet simulation is started after pressing GO, participants should try to click on moths as fast as they can with the mouse.  

Each participant can monitor his or her relative success compared to other participants by watching the monitors in the client that show the TOP HUNTER (the person with most catches), how many that person eaten (TOP HUNTER'S EATEN) and the RELATIVE % they have caught compared to the best hunter (e.g. if the player has caught 40 and the best hunter has caught 80, then s/he has 50%).  

Over time a small population of moths will become harder and harder to detect in the environment (the environment is an image file that is loaded into the model).  Camouflaging emerges from: 1) a selective pressure that results from the interaction of predator, prey, and environment, 2) the genetic representation for genes to show color, 3) and small random changes that accumulate in new offspring in the remaining population that tend to be more advantageous.

Trying to become the best hunter (in number of moth catches) in the HubNet environment helps simulate the competitive pressure for limited food resources that exists between individual predators in a population.  Without this simulated competition, a participant could leisurely hunt for moths regardless of how easy they are to catch or find.  This would not put any selective pressure on the moth population over time, and so camouflaging would not emerge in the population.

Camouflaging emerges because of the selective pressure of the hunters (the participants) and the way in which small changes in moth color can accumulate in a population over time.  Individual moths have 3 genes that determine their phenotype for color (red-pigment-gene-frequency, green-pigment-gene-frequency, blue-pigment-gene-frequency).  The more frequently the gene for a pigment is coded for, the stronger that presence of color is in the overall blend of pigments that results in a single phenotype for coloration.

With each bug you eat, a new bug is randomly chosen to reproduce one additional offspring.  The offspring's gene-frequency for the three gene pigments may be different than the parent's (as determined by the mutation-step global variable).  Through this effect the offspring usually have a color close to its parent, but is also either slightly easier or harder to see (e.g. more red vs. less red, brighter vs. darker, etc..)


HOW TO USE IT
-------------
Make sure you select Mirror 2D view on clients in the HubNet Control Center after you press SETUP.

NUMBER-MOTHS determines the population level on SETUP and how many moths are in the world at one time when GO is pressed and moths are being eaten.

OFFSPRING-DISTANCE determines how far away an offspring could show up from a parent.  For example, an offspring-distance of 5 means the offspring could be 0, 1, 2, 3, 4, or 5 patches away from the parent.

MOTH-SIZE can be changed during GO or before SETUP to change the size of the shapes for the moths.  

SHOW-GENOTYPE? reveals the rgb values for the genes for each moth.

When DAY-NIGHT? is true the world cycles from daytime to nighttime every DAY-LENGTH ticks.  At night the view turns black for NIGHT-WAIT seconds, so you cannot see the moths or the background.  The moths will then move around up to WANDER-DISTANCE around the world. This enhances the camouflaging effect for the offspring.

TICKS-DURING-DAY is a counter that cycles back to zero each time the view goes black (when it is nighttime), and counts up to DAY-LENGTH. 

FLASH flashes the moths in the view in case you are convinced they are no longer there, even though they may simply be very well hidden.

ENVIRONMENT specifies the file name to load as a background on SETUP or on CHANGE-BACKGROUND.  The image file should be located in the same directory as the model to load correctly.

MAKE A GENERATION creates one offspring from each of the existing moths, without being limited by the NUMBER-MOTHS.

TOTAL-CAUGHT keeps track of how many moths all the participants have caught.


THINGS TO TRY
-------------
Larger numbers of moths tend to take longer to start camouflaging, but larger numbers of prey speed up the camouflaging.

A common response from the participants at some point in using the models with a low population of moths (e.g. 10) will be "where did the moths all go?" With a larger population of moths, some participants might say "why are the moths harder to see now?" Not all participants may see this effect the first time, try to run the model again with a new environment, or change the environment as the participants are hunting (by pressing CHANGE-BACKGROUND with a different setting in the ENVIRONMENT chooser). Changing the environment in the middle of the hunting may show that it takes a lot longer for the population to respond and shift to camouflaging for this new environment.  It may seem slower for the population of prey to respond to this opportunity if it has few individuals and low genetic diversity (they all look about the same color).  Eventually, however, if you keep playing with the model the user might get better at finding the moths, but if the user keeps trying to catch bugs quickly, even an experienced user will find that the moths will become very hard to find relatively quickly in certain environments.

The DAY-NIGHT? makes memorizing the location of moths and offspring harder to do.  When DAY-NIGHT? is turned off, it is easy to see the sudden appearance of something new in the environment and go after it.  If, however, the environment is hidden briefly (DAY-NIGHT? set to true for some length of time), it harder for the user to make "photographic comparison" of the environment to hunt for new offspring that are better camouflaged.

Sometimes two or more "near background" colors emerge as a predominant feature in a population of moths.  An example of this is the appearance of mostly green and red moths in the poppy field, or dark blue/black and snow blue in the glacier background.  Other times, the saturation of the moths appears to be selected for.  An example of this is a common outcome of "shell colored" moths on the seashore background (e.g. light yellow, light tan, and light blue moths similar to the shells of the seashore).

In environments that have two distinct areas (such as a ground and sky), each with their own patterns and background colors, you might see two distinct populations of different camouflaging outcomes.  Adjusting the various wander sliders may accentuate this effect.

Once you reach a point where you are having trouble finding the moths, it is useful to press FLASH-MOTHS to show you where they are so you can see how they are camouflaged.


EXTENDING THE MODEL
-------------------
What if moths reproduced sexually and recombined gene frequencies in their offspring?

What if the shape of the moths changed?

What if a second population of insects, with slightly different body shape, was poisonous, and lost points for the user when they selected it?  Would the moths drift to become more like this color (Mimicry), stay more like the environment, or some other outcome?


NETLOGO FEATURES
----------------
IMPORT-DRAWING is the primitive that loads the image into the drawing, which in this case is merely a backdrop.

IN-RADIUS? is the primitive that checks to see if the mouse is within the graphical footprint/boundaries of a turtle that is not size 1.

RGB converts the gene-pigments (genotype) to a NetLogo color (phenotype) to display in the view.


RELATED MODELS
--------------
Bug Hunt Speeds
Bug Hunt Camouflage
Peppered Moths
Guppy Spots


CREDITS AND REFERENCES
----------------------
Inspired by this BugHunt! Macintosh freeware: http://bcrc.bio.umass.edu/BugHunt/.

Thanks to Michael Novak for his work on the design of this model and the EvoLab curriculum.

To refer to this model in academic publications, please use:  Wilensky, U. (2006).  NetLogo HubNet Bug Hunters Camouflage model.  http://ccl.northwestern.edu/netlogo/models/HubNetBugHuntersCamouflage.  Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

In other publications, please use:  Copyright 2006 Uri Wilensky.  All rights reserved.  See http://ccl.northwestern.edu/netlogo/models/HubNetBugHuntersCamouflage for terms of use.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

hawk
true
0
Polygon -7500403 true true 166 230 165 255 138 289 158 304 171 304 194 289 165 255
Polygon -16777216 true false 166 222 165 247 143 285 155 295 176 294 189 285 165 247
Polygon -7500403 true true 175 164 174 151 164 144 145 143 154 152 148 171 142 203 150 240 154 262 165 296 175 264 180 240 184 201
Polygon -7500403 true true 153 175 224 159 285 179 271 183 293 199 275 200 286 213 269 213 277 223 263 220 266 227 227 232 152 229
Circle -16777216 true false 159 145 7
Polygon -16777216 true false 144 143 150 148 154 144
Polygon -7500403 true true 168 171 94 158 35 177 51 182 27 197 45 198 34 211 51 211 43 221 57 218 54 225 93 230 168 227
Polygon -7500403 true true 165 214 164 239 142 277 154 287 175 286 188 277 164 239
Polygon -16777216 true false 171 251 164 246 143 270 155 280 176 279 189 270 161 251
Polygon -7500403 true true 165 201 164 226 149 261 154 274 175 273 181 260 164 226
Polygon -16777216 false false 145 142 154 152 149 168 92 158 33 176 49 182 25 196 45 197 33 211 52 211 42 221 57 218 52 225 93 231 147 228 150 240 150 252 149 267 143 271 145 272 141 276 145 281 137 289 150 300 177 300 194 289 184 279 189 275 185 274 188 271 179 262 181 258 176 253 181 240 181 230 228 233 267 227 261 219 277 222 267 213 286 213 275 200 292 198 271 182 285 178 226 159 175 170 174 151 164 144

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

moth
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -7500403 true true 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -7500403 true true 135 90 30
Line -7500403 true 150 105 195 60
Line -7500403 true 150 105 105 60

moth-black
true
0
Polygon -16777216 true false 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -16777216 true false 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -16777216 true false 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -16777216 true false 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

moth-white
true
0
Polygon -1 true false 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -1 true false 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -1 true false 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -1 true false 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -1 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -1 true false 135 90 30
Line -1 false 150 105 195 60
Line -1 false 150 105 105 60

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 0 0 300 300

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 3.1beta5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
